Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(123)

Unified Diff: third_party/WebKit/public/platform/modules/webusb/WebUSBDevice.h

Issue 1635903004: Add support for isochronous transfers in WebUSB. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@usb_isoc
Patch Set: Fix tense. Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/platform/modules/webusb/WebUSBDevice.h
diff --git a/third_party/WebKit/public/platform/modules/webusb/WebUSBDevice.h b/third_party/WebKit/public/platform/modules/webusb/WebUSBDevice.h
index a9da9ff44873a9a5e9509f707db393fa2ac8ce98..70a8d149e1ee05e31557dc25878d5c3e75921a66 100644
--- a/third_party/WebKit/public/platform/modules/webusb/WebUSBDevice.h
+++ b/third_party/WebKit/public/platform/modules/webusb/WebUSBDevice.h
@@ -26,12 +26,6 @@ using WebUSBDeviceSetInterfaceAlternateSettingCallbacks = WebCallbacks<void, con
using WebUSBDeviceClearHaltCallbacks = WebCallbacks<void, const WebUSBError&>;
using WebUSBDeviceTransferCallbacks = WebCallbacks<WebPassOwnPtr<WebUSBTransferInfo>, const WebUSBError&>;
-// TODO(rockot): Eliminate these aliases once they're no longer used outside of
-// Blink code.
-using WebUSBDeviceControlTransferCallbacks = WebUSBDeviceTransferCallbacks;
-using WebUSBDeviceBulkTransferCallbacks = WebUSBDeviceTransferCallbacks;
-using WebUSBDeviceInterruptTransferCallbacks = WebUSBDeviceTransferCallbacks;
-
class WebUSBDevice {
public:
enum class TransferDirection {
@@ -98,12 +92,16 @@ public:
virtual void clearHalt(uint8_t endpointNumber, WebUSBDeviceClearHaltCallbacks*) = 0;
// Initiates a control transfer.
- // Ownership of the WebUSBDeviceControlTransferCallbacks is transferred to the client.
- virtual void controlTransfer(const ControlTransferParameters&, uint8_t* data, size_t dataSize, unsigned timeout, WebUSBDeviceControlTransferCallbacks*) = 0;
+ // Ownership of the WebUSBDeviceTransferCallbacks is transferred to the client.
+ virtual void controlTransfer(const ControlTransferParameters&, uint8_t* data, size_t dataSize, unsigned timeout, WebUSBDeviceTransferCallbacks*) = 0;
// Initiates a bulk or interrupt transfer.
- // Ownership of the WebUSBDeviceBulkTransferCallbacks is transferred to the client.
- virtual void transfer(TransferDirection, uint8_t endpointNumber, uint8_t* data, size_t dataSize, unsigned timeout, WebUSBDeviceBulkTransferCallbacks*) = 0;
+ // Ownership of the WebUSBDeviceTransferCallbacks is transferred to the client.
+ virtual void transfer(TransferDirection, uint8_t endpointNumber, uint8_t* data, size_t dataSize, unsigned timeout, WebUSBDeviceTransferCallbacks*) = 0;
+
+ // Initiates an isochronous transfer.
+ // Ownership of the WebUSBDeviceTransferCallbacks is transferred to the client.
+ virtual void isochronousTransfer(TransferDirection, uint8_t endpointNumber, uint8_t* data, size_t dataSize, WebVector<unsigned> packetLengths, unsigned timeout, WebUSBDeviceTransferCallbacks*) = 0;
// Resets the device.
// Ownership of the WebUSBDeviceResetCallbacks is transferred to the client.

Powered by Google App Engine
This is Rietveld 408576698